#ifndef __KP_NEW_COMMENT_DIALOG_H
#define __KP_NEW_COMMENT_DIALOG_H

#include <gtk/gtk.h>
#include "kpaddeditdialog.h"
#include "kpcalendarview.h"
#include "../kptraininglog.h"
#include "../kpcomment.h"

#define KP_TYPE_NEW_COMMENT_DIALOG         (kp_new_comment_dialog_get_type ())
#define KP_NEW_COMMENT_DIALOG(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), KP_TYPE_NEW_COMMENT_DIALOG, KPNewCommentDialog))
#define KP_NEW_COMMENT_DIALOG_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), KP_TYPE_NEW_COMMENT_DIALOG, KPNewCommentDialogClass))
#define KP_IS_NEW_COMMENT_DIALOG(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), KP_TYPE_NEW_COMMENT_DIALOG))
#define KP_IS_NEW_COMMENT_DIALOG_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), KP_TYPE_NEW_COMMENT_DIALOG))
#define KP_NEW_COMMENT_DIALOG_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), KP_TYPE_NEW_COMMENT_DIALOG, KPNewCommentDialogClass))

typedef struct
{
  KPAddEditDialog       parent;

  gpointer              private_data;
} KPNewCommentDialog;

typedef struct
{
  KPAddEditDialogClass  parent_class;
} KPNewCommentDialogClass;

GType           kp_new_comment_dialog_get_type (void);

GtkWidget      *kp_new_comment_dialog_new (KPDate *date, KPComment *comment);

#endif /* __KP_NEW_COMMENT_DIALOG_H */
